#/bin/bash
#
# All Rights Reserved, Copyright (c) FUJITSU LIMITED 2012-2017
#
#	Configuration Tool for Oracle VM Server for SPARC
#
# Revision 3.0  2017/11/05
#
# io_custom.sh

io_custom()
{

#---set default------------------------------------------------------------#
CPU_MIN=1
CPU_DEF=1
MEM_MIN=4096
MEM_DEF=4096
MIN_VDISK=1
#--------------------------------------------------------------------------#
TITLE=" 3. Configure an I/O domain or Service Domain"
DKIND="I/O"
PATTERN="Original"
#work_out="${work_dir}/${DOMAIN}"

############################################################################
# Creating Domain
############################################################################

#---get domain name--------------------------------------------------------#

NAME=`ldm ls -p | grep DOMAIN | sed -e 's/name=//' -e 's/ncpu=//' | awk -F"|" '{print $2}'`

#--------------------------------------------------------------------------#

header "$TITLE" "$PATTERN"
print "# Logical domain name and Host ID                                                [1/8]"
print ""
print "Specify a logical domain name for the guest domain."
print ""
print "t:top menu  q:quit"
print "---------------------------------------------------------------------------------------"
print ""

domain_name

work_out="${work_dir}/${DOMAIN}"

host_id

echo ""
echo "=== The following logical domain name and host ID will be set ==="
cat $work_out/dom.tmp
echo "---------------------------------------------------------------------------------------"
echo "Please press the enter key."
read key

############################################################################
# CPU cores
############################################################################

	print_cpu
	header "$TITLE" "$PATTERN"
print "# CPU cores                                                                      [2/8]"
print ""
printf "Assign CPU cores to the domain %s.\n" "$DOMAIN"
print ""
print "### Current CPU allocation for each domain ###"
print ""
cat $work_dir/cpulist.tmp
print "t:top menu  q:quit"
print "---------------------------------------------------------------------------------------"
print ""

domain_cpu 1

if [ -f $work_out/cpu.info ];then
	echo "=== The following quantity of CPU cores will be allocated ==="
	cat $work_out/cpu.info
else
	echo ""
	echo "CPU core will not be allocated."
fi
echo "---------------------------------------------------------------------------------------"
echo "Please press the enter key."
read key

############################################################################
# Setting Memory
############################################################################

header "$TITLE" "$PATTERN"
print_memory

print "# Memory                                                                         [3/8]"
print ""
printf "Assign memory to the domain %s.\n" "$DOMAIN"
print ""
print "### The current amount of memory allocated to each domain ###"
print ""
cat $work_dir/memlist.tmp
print "t:top menu  q:quit"
print "---------------------------------------------------------------------------------------"
print ""

domain_memory

echo "=== The following memory will be allocated ==="
cat $work_out/mem.tmp
echo "---------------------------------------------------------------------------------------"
echo "Please press the enter key."
read key

############################################################################
# Allocate Network VF(SR-IOV)
############################################################################

header "$TITLE" "$PATTERN"
print "# Virtual Network                                                                [4/8]"
print ""
print "Do you wish to allocate a virtual network (Network VF)?"
print ""
print "t:top menu  q:quit"
print "---------------------------------------------------------------------------------------"
print ""

while :
do
	YN=""
	echo "Allocate a virtual network? ([y]/n) ==> \c"
	read YN
	case ${YN:-y} in
		[t])	top
			continue
			;;
		[q])	quit
			continue
			;;
		[n])	NUM_of_VNET=0
			break
			;;
		[y])	break
			;;
		  *)	continue
			;;
	esac
done

if [ "${YN:-y}" = y ]; then
	echo "Please select a number to allocate VF device from the following list."
	print_nicvf
	assign_nicvf
fi

if [ ${NUM_of_VNET:-1} -eq 0 ];then
	echo ""
	echo "A virtual network will not be created."
else
	if [ -f $work_out/nicvf.info ];then
		echo ""
		echo "=== The following virtual network setting will be set ==="
		cat $work_out/nicvf.info
	else
		echo ""
		echo "A virtual network will not be created."
	fi
fi

echo "---------------------------------------------------------------------------------------"
echo "Please press the enter key."
read key

############################################################################
# Allocate FiberChannel VF(SR-IOV)
############################################################################

header "$TITLE" "$PATTERN"
print "# Virtual I/O device                                                             [5/8]"
print ""
print "Do you wish to allocate a virtual I/O device (Fiber Channel VF)?"
print ""
print "t:top menu  q:quit"
print "---------------------------------------------------------------------------------------"
print ""

while :
do
	YN=""
	echo "Allocate a virtual I/O device? ([y]/n) ==> \c"
	read YN
	case ${YN:-y} in
		[t])	top
			continue
			;;
		[q])	quit
			continue
			;;
		[n])	NUM_of_ASVF=0
			break
			;;
		[y])	break
			;;
		  *)	continue
			;;
	esac
done

if [ "${YN:-y}" = y ]; then
	echo "Please select a number to allocate VF device from the following list."
	print_fcvf
	assign_fcvf
fi

if [ ${NUM_of_ASVF:-1} -eq 0 ];then
	echo ""
	echo "A virtual I/O device will not be created."
else
	if [ -f $work_out/fcvf.info ];then
		echo ""
		echo "=== The following virtual I/O device setting will be set ==="
		cat $work_out/fcvf.info
	else
		echo ""
		echo "A virtual I/O device will not be created."
	fi
fi

echo "---------------------------------------------------------------------------------------"
echo "Please press the enter key."
read key

############################################################################
# Select OS install 
############################################################################

header "$TITLE" "$PATTERN"
print "# OS Install                                                                     [6/8]"
print ""
printf "Select a method to install the Oracle Solaris OS on the logical domain %s.\n" "$DOMAIN"
print "Please select either installation from a network install server for from an iso image"
print "file."
print ""
print "t:top menu  q:quit"
print "---------------------------------------------------------------------------------------"
print ""

os_install 1

if [ -f $work_out/os.info ];then
	echo "=== The following method will be set ==="
	cat $work_out/os.info
else
	echo ""
	echo "Not decided."
fi

echo "---------------------------------------------------------------------------------------"
echo "Please press the enter key."
read key

############################################################################
# Setting VC
############################################################################

header "$TITLE" "$PATTERN"
print "# Virtual Console                                                                [7/8]"
print ""
print "Set a virtual console (vc) to access to each domain's console."
print ""
print "t:top menu  q:quit"
print "---------------------------------------------------------------------------------------"
print ""

VCC_LIST=`ldm ls -l -p | grep VCC | awk -F"|" '{print $2}' | sed -e 's/name=//'`
echo "Please select a virtual console concentrator for $DOMAIN from the following list:"

c01=0
for i in `echo $VCC_LIST`
do
	c01=`expr $c01 + 1`
	echo " $c01. $i"
done 

while :
do
	echo "Enter a number [1] ==> \c"
	read i
	case ${i:-1} in
		[t])	top
			continue
			;;
		[q])	quit
			continue
			;;
		[0])	echo "ERROR: Invalid input value."
			echo ""
			continue
			;;
		  *)	expr ${i:-1} + 1 > /dev/null 2>&1
			if [ $? -ne 0 ];then
				echo "ERROR: Invalid input value."
				echo ""
			elif [ ${i:-1} -gt 0 -a ${i:-1} -le $c01 ];then
				VCC=`echo $VCC_LIST | awk '{print $'${i:-1}'}'`
				break
			else
				echo "ERROR: Invalid input value."
				echo ""
			fi
			;;
	esac
done

add_vcc

echo ""
echo "=== The following virtual console settings will be made ==="
if [ -f $work_out/vc.tmp ];then
	cat $work_out/vc.info
else
	echo "VC for $DOMAIN is not specified."
fi
echo "---------------------------------------------------------------------------------------"
echo "Please press the enter key."
read key

############################################################################
# Setting Variables
############################################################################

header "$TITLE" "$PATTERN"
print "# Boot-parameters                                                                [8/8]"
print ""
print "Set the \"auto-boot?\" and \"boot-device\" OBP parameters for the logical domain."
print ""
print "t:top menu  q:quit"
print "---------------------------------------------------------------------------------------"
print ""

set_var

echo ""
echo "=== The following boot parameters will be set ==="
if [ -f $work_out/var.tmp ];then
	cat $work_out/var.info
else
	echo "OBP for $DOMAIN is not specified."
fi
echo "---------------------------------------------------------------------------------------"
echo "Please press the enter key."
read key

############################################################################
# Confirmation of setting
############################################################################

header "$TITLE" "$PATTERN"
print "The following I/O domain configuration will be set."
print ""
printf "======= Your configuration information for guest domain %s =======================\n" "$DOMAIN"
if [ -f $work_out/dom.tmp ];then cat $work_out/dom.tmp ;fi
if [ -f $work_out/cpu.info ];then cat $work_out/cpu.info ;fi
if [ -f $work_out/mem.tmp ];then cat $work_out/mem.tmp  ;fi
print "-------------------------------------------------------------------"
if [ -f $work_out/nicvf.info ];then cat $work_out/nicvf.info ;fi
if [ -f $work_out/fcvf.info ];then cat $work_out/fcvf.info ;fi
if [ -f $work_out/vc.tmp ];then cat $work_out/vc.info ;fi
if [ -f $work_out/var.tmp ];then cat $work_out/var.info ;fi
print "-------------------------------------------------------------------"
if [ -f $work_out/os.info ];then cat $work_out/os.info ;fi
print "======================================================================================="
print ""

############################################################################
# Execution and creating of configuration file
############################################################################

EXE=$conf_dir/${DOMAIN}-${DATE}.sh

save_exec 0

############################################################################
# Delete temporary file 
############################################################################

delete
############################################################################

}
