#/bin/bash
#
# All Rights Reserved, Copyright (c) FUJITSU LIMITED 2012-2017
#
#	Configuration Tool for Oracle VM Server for SPARC
#
# Revision 3.0  2017/10/28
#
# custom_io_root.sh

io_root_custom()
{

#---set default------------------------------------------------------------#
CPU_MIN=1
CPU_DEF=1
MEM_MIN=4096
MEM_DEF=4096
#--------------------------------------------------------------------------#
TITLE=" 4. Configure an I/O domain or Service Domain"
DKIND="I/O root"
PATTERN="Original"
#work_out="${work_dir}/${DOMAIN}"

############################################################################
# Select Create new I/O root domain or Setup service domain
############################################################################

new_or_setup()
{
header "$TITLE" "$PATTERN"
print "Do you wish to create a new I/O root domain or add a service domain function to an I/O domain?"
print ""
print " 1. Create new I/O root domain."
print " 2. Add a service domain function to an I/O domain."
print ""
print ""
print "t:top menu  q:quit"
print "---------------------------------------------------------------------------------------"
print ""

while :
do
	echo "Please select (1-2,t,q) ==> \c"
	read i
	case ${i:-} in
		[t])	top
			;;
		[q])	quit
			;;
		[1])	break
			;;
		[2])	DOMAIN_LIST=`ldm ls-io -p | grep type=BUS | awk -F"|" '{print $5}' | sed -e s/domain=// | grep -v primary | sed -e /^$/d | sort -u`
			if [ -f $work_dir/service_domain_list ];then
				rm $work_dir/service_domain_list
			fi
			if [ "$DOMAIN_LIST" != "" ];then
				for i in $DOMAIN_LIST
				do
					DOMAIN_STATUS=`ldm ls -p | grep $i | awk -F"|" '{print $4}' | cut -c 8`
					if [ "$DOMAIN_STATUS" = "n" ];then
						echo $i >> $work_dir/service_domain_list
					fi
				done
			fi
			if [ -f $work_dir/service_domain_list ];then
				service_custom
				exit 0
			else	
				echo ""
				echo "---------------------------------------------------------------------------------------"
				echo "There is no I/O root domain currently running the Solaris OS. You must first install the"
				echo "Solaris OS and start the I/O root domain for which you want to set the service domain."
				echo "---------------------------------------------------------------------------------------"
				echo ""
				while :
				do
					echo "Please select (t,q) ==> \c"
					read j
					case $j in
					  [t])	top
						;;
					  [q])	quit
						;;		
					    *)	echo "ERROR: Invalid input value."
						continue
					esac
				done
				exit 0	
			fi
			;;
		  *)	continue
			;;
	esac
done
}

EXIST=`ldm ls | sed -n 3p`
if [ "$EXIST" != "" ];then
	new_or_setup
fi

############################################################################
# Creating Domain
############################################################################

#---check the removed I/O device--------------------------------------------#

ldm list-io -p | grep "type=BUS" > $work_dir/listio_$$

CHECK_IO=NG
for i in `cat $work_dir/listio_$$`
do
	LINE=(`echo $i | sed -e 's/|/ /g'`)
	if [ "${LINE[3]}" = "domain=" ];then
		CHECK_IO=OK
	fi
done

if [ "$CHECK_IO" = "NG" ];then
	header "$TITLE" "$PATTERN"
	print "Please remove the I/O device from the control domain before you create the I/O root domain."
	print ""
	print ""
	print "---------------------------------------------------------------------------------------"
	print ""
	echo "Please press the enter key. \c"
	read
	delete
	menu
	exit 0
fi

############################################################################
# Creating Domain 
############################################################################

header "$TITLE" "$PATTERN"
print "# Logical domain name and Host ID                                                [1/8]"
print ""
print "Specify a logical domain name for the I/O root domain."
print ""
print "t:top menu  q:quit"
print "---------------------------------------------------------------------------------------"
print ""

domain_name

work_out="${work_dir}/${DOMAIN}"

host_id

echo ""
echo "=== The following logical domain name and host ID will be set ==="
cat $work_out/dom.tmp
echo "---------------------------------------------------------------------------------------"
echo "Please press the enter key."
read key

############################################################################
# CPU cores
############################################################################

print_cpu

header "$TITLE" "$PATTERN"
print "# CPU cores                                                                      [2/8]"
print ""
printf "Assign CPU cores to the domain %s.\n" "$DOMAIN"
print ""
print "### Current CPU allocation for each domain ###"
print ""
cat $work_dir/cpulist.tmp
print "t:top menu  q:quit"
print "---------------------------------------------------------------------------------------"
print ""

domain_cpu 1

if [ -f $work_out/cpu.info ];then
	echo "=== The following quantity of CPU cores will be allocated ==="
	cat $work_out/cpu.info
else
	echo ""
	echo "CPU core will not be allocated."
fi

echo "---------------------------------------------------------------------------------------"
echo "Please press the enter key."
read key

############################################################################
# Setting Memory
############################################################################

header "$TITLE" "$PATTERN"
print_memory
print "# Memory                                                                         [3/8]"
print ""
printf "Assign memory to the domain %s.\n" "$DOMAIN"
print ""
print "### The current amount of memory allocated to each domain ###"
print ""
cat $work_dir/memlist.tmp
print "t:top menu  q:quit"
print "---------------------------------------------------------------------------------------"
print ""

domain_memory

echo "=== The following memory will be allocated ==="
cat $work_out/mem.tmp
echo "---------------------------------------------------------------------------------------"
echo "Please press the enter key."
read key

############################################################################
# Adding I/O
############################################################################

header "$TITLE" "$PATTERN"
print "# Add I/O devices to the I/O root domain.                                        [4/8]"
print ""
print "Please select I/O devices that you wish to add to the I/O root domain."
print ""
print_io | tee -a $work_dir/iolist.tmp
print ""
print "t:top menu  q:quit"
print "---------------------------------------------------------------------------------------"
print ""

COUNT1=0
COUNT2=`cat $work_dir/iolist.tmp |grep BUS | wc -l`

while [ $COUNT1 -lt $COUNT2 ]
do
	A=(`cat $work_dir/iolist.tmp | sed -n '/^ '$COUNT1'/p' | awk '{print $2,$4,$5}'`)
	if [ "${A[1]}" = "" ];then
		YN=""
		echo "Add I/O device No. "$COUNT1" ? (y/[n]) ==> \c"
		read YN
		case ${YN:-n} in
			[t])	top
				continue
				;;
			[q])	quit
				continue
				;;
			[n])	
				;;
			[y])	echo "I/O    : added ${A[0]} to the domain $DOMAIN." >> $work_out/add_io.tmp
				;;
			  *)	continue
				;;
		esac
	else
		echo "The No. $COUNT1 device has already been allocated to the `echo ${LINE[3]} | cut -c 8-` domain."
		echo "Please press the enter key. \c"
		read
	fi

	COUNT1=`expr $COUNT1 + 1`
done

if [ -f $work_out/add_io.tmp ];then
	echo ""
	echo "=== The following I/O devices will be added  ==="
	cat $work_out/add_io.tmp
else
	echo "$DOMAIN has NO I/O devices."
fi

echo "---------------------------------------------------------------------------------------"
echo "Please press the enter key."
read key

############################################################################
# Select OS install
############################################################################

header "$TITLE" "$PATTERN"
print "# OS Install                                                                     [5/8]"
print ""
printf "Select a method to install the Oracle Solaris OS on the logical domain %s.\n" "$DOMAIN"
print "Please select either installation from a network install server for from an iso image"
print "file."
print ""
print "t:top menu  q:quit"
print "---------------------------------------------------------------------------------------"
print ""

os_install 0

print ""

if [ -f $work_out/os.info ];then
	echo "=== The following method will be set ==="
	cat $work_out/os.info
else
	echo ""
	echo "Not decided."
fi
echo "---------------------------------------------------------------------------------------"
echo "Please press the enter key."
read key

############################################################################
# Setting VC
############################################################################

header "$TITLE" "$PATTERN"
print "# Virtual Console                                                                [6/8]"
print ""
print "Set a virtual console (vc) to access to each domain's console."
print ""
print "t:top menu  q:quit"
print "---------------------------------------------------------------------------------------"
print ""

VCC=`ldm ls -l -p | grep VCC | grep primary | awk -F"|" '{print $2}' | sed -e 's/name=//'`

add_vcc

echo ""
echo "=== The following virtual console settings will be made ==="
if [ -f $work_out/vc.info ];then
	cat $work_out/vc.info
else
	echo "VC for $DOMAIN is not specified."
fi
echo "---------------------------------------------------------------------------------------"
echo "Please press the enter key."
read key

############################################################################
# Setting Variables
############################################################################

header "$TITLE" "$PATTERN"
print "# Boot-parameters                                                                [7/8]"
print ""
print "Set the \"auto-boot?\" and \"boot-device\" OBP parameters for the logical domain."
print ""
print "t:top menu  q:quit"
print "---------------------------------------------------------------------------------------"
print ""

set_var

echo ""
echo "=== The following boot parameters will be set ==="
if [ -f $work_out/var.tmp ];then
	cat $work_out/var.tmp
else
	echo "OBP for $DOMAIN is not specified."
fi
echo "---------------------------------------------------------------------------------------"
echo "Please press the enter key."
read key

############################################################################
# Setting Service Domain
############################################################################

header "$TITLE" "$PATTERN"
print "# Service Domain                                                                 [8/8]"
print ""
print "A service domain function can be added to the I/O root domain."
print ""
print "t:top menu  q:quit"
print "---------------------------------------------------------------------------------------"
print ""

while :
do
	YN=""
	echo "Do you wish to add a service domain function to the I/O root domain? (y/n) ==> \c"
	read YN
	case $YN in
		[t])	top
			;;
		[q])	quit
			;;
		[y])	
			echo ""
			echo "---------------------------------------------------------------------------------------"
			echo "The Solaris OS must be installed on the I/O root domain before adding the service domain"
			echo "fucntion. Please run this tool again after the OS installation and select \"2. Add a"
			echo "service domain function to an I/O root domain.\""
			echo "---------------------------------------------------------------------------------------"
			echo "Please press the enter key."
			read key
			break
			;;
		[n])	break
			;;
		*)	echo "Please select y or n."
			;;
	esac
done

############################################################################
# Confirmation of setting
############################################################################

header "$TITLE" "$PATTERN"
print "The following I/O root domain configuration will be set."
print ""
printf "======= Your configuration information for I/O root domain %s =========================\n" "$DOMAIN"
if [ -f $work_out/dom.tmp ];then cat $work_out/dom.tmp ;fi
if [ -f $work_out/cpu.info ];then cat $work_out/cpu.info ;fi
if [ -f $work_out/mem.tmp ];then cat $work_out/mem.tmp ;fi
if [ -f $work_out/add_io.tmp ];then cat $work_out/add_io.tmp ;fi
echo "-------------------------------------------------------------------"
if [ -f $work_out/var.info ];then cat $work_out/var.info ;fi
if [ -f $work_out/vc.tmp ];then cat $work_out/vc.info ;fi
echo "-------------------------------------------------------------------"
if [ -f $work_out/os.info ];then cat $work_out/os.info ;fi
print "======================================================================================="
print ""

############################################################################
# Execution and creating of configuration file
############################################################################

EXE=$conf_dir/${DOMAIN}-${DATE}.sh

save_exec 0

############################################################################
# Delete temporary file 
############################################################################

delete
############################################################################

}
