#!/bin/sh
#
# All Rights Reserved, Copyright (c) FUJITSU LIMITED 2012-2014
#
#	Configuration Tool for Oracle VM Server for SPARC
#
# Revision 2.2  2014/10/02
#
# init_all.sh

init_all()
{

#---set default------------------------------------------------------------#
#DOMAIN="guest"
TITLE=" The Configuration Tool for Oracle VM Server for SPARC"
DKIND="initial"
PATTERN="Initialize"
#work_out="${work_dir}/${DOMAIN}"
#--------------------------------------------------------------------------#

############################################################################
# Initialize all domain's configuration
############################################################################

#---get domain name--------------------------------------------------------#

ALL_GUEST=`ldm ls -p | grep DOMAIN | awk -F"|" '{print $2}' | sed -e s/name=// | grep -v primary`

#---get config name--------------------------------------------------------#

ALL_CONFIG=`ldm list-config | grep -v factory-default | awk '{print $1}'`

#--------------------------------------------------------------------------#

header "$TITLE" "$PATTERN"
print "# Confirm the Initialization                                                       [1/2]"
print ""
print "Do you wish to remove all guest domains and all logical domains configurations and"
print "restore the factory default configuration?"
print ""
print ""
print "t:top menu  q:quit"
print "---------------------------------------------------------------------------------------"
print ""

while :
do
	echo "Are you sure? (y/[n]) ==> \c"
	read YN
	case ${YN:-n} in
	  [t])	top
		continue
		;;
	  [q])	quit
		continue
		;;
	  [y])	echo ""
		echo "=== The following guest domains and configurations will remove ==="
		for i in $ALL_GUEST
		do
			echo "DOMAIN: $i"
		done
		echo "-------------------------------------------------------------------"
		for j in $ALL_CONFIG
		do
			echo "CONFIG: $j"
		done
		break
		;;
	  [n])	echo ""
		exit 0
		;;
	    *)	echo "Please enter y(yes) or n(no)."
		continue
		;;
	esac
done

echo "-------------------------------------------------------------------"
echo "Please press the enter key."
read key

############################################################################
# Execution and creating of initializing file
############################################################################

header "$TITLE" "$PATTERN"
print "# Create the file for the initialization                                           [2/2]"
print ""
print "Creating the script file for initializing the configuration."
print ""
print ""
print "t:top menu  q:quit"
print "---------------------------------------------------------------------------------------"
print ""

EXE=$conf_dir/init-all-${DATE}.sh

while :
do
	YN=""
	echo "This tool makes a configuration file that can be used to remove all domains and"
	echo "configurations and restore the factory-default configuration."
	echo "Save this configuration file? If no, the configuration will be cleared. (y/n) ==> \c"
	read YN
	case $YN in
	  [y])	echo "#!/bin/sh" > $EXE
		echo "#Creation date:`LC_TIME=C;date`" >> $EXE
		echo "" >> $EXE
		echo "PATH=$PATH ; export PATH" >> $EXE
		echo "" >> $EXE

		#---- Destroy Domain ------------------------------#

		echo "ldm stop-domain -f -a" >> $EXE
		for DOMAIN in $ALL_GUEST 
		do
			guest=`ldm ls | grep $DOMAIN | awk -F" " '{print $3}' | grep v`
			if [ -z ${guest} ]; then
				echo "ldm unbind-domain $DOMAIN > /dev/null 2>&1" >> $EXE
			fi
		done
		for DOMAIN in $ALL_GUEST 
		do
			guest=`ldm ls | grep $DOMAIN | awk -F" " '{print $3}' | grep v`
			if [ ${guest} ]; then
				echo "ldm unbind-domain $DOMAIN > /dev/null 2>&1" >> $EXE
			fi
		done
		echo "ldm remove-domain -a" >> $EXE

		#---- Delete configuration file -------------------#

		echo "ldm set-config factory-default" >> $EXE
		for CONFIG in $ALL_CONFIG
		do
			echo "ldm remove-config $CONFIG" >> $EXE
		done

		#--------------------------------------------------#

		echo ""
		echo "The configuration file ($EXE) was saved."
		echo ""
		chmod +x $EXE

		while :
		do
			YN=""
			echo "Do you wish to initialize the all domain's configuration now with this file? (y/n) ==> \c"
			read YN
			case $YN in
			  [y])	echo "Currently, initialize the configuration domain with the file($EXE)."
				echo ""
				$EXE
				echo ""
				echo "---------------------------------------------------------------------------------------"
				echo "If error messages are displayed, please check if initialization of the domain failed."
				echo "If no messages are displayed, the domain was initialized successfully."
				echo "Please reboot the server (poweroff/poweron) after pressing the enter key."
				read key
				break 2
				;;
			  [n])	echo "---------------------------------------------------------------------------------------"
				echo "The domain's configuration was not initialized."
				echo "If you wish to initialize the domain with this file later, please execute the following"
				echo "command and then reboot the server (poweroff/poweron)."
				echo "# $EXE"
				echo "Please press the enter key."
				read key
				break 2
				;;
			    *)	echo "Please enter y(yes) or n(no)."
				continue
				;;
			esac
		done
		;;
	  [n])	echo "The operation was aborted, and the configuration file for initialization was not saved."
		break
		;;
	    *)	echo "Please enter y(yes) or n(no)."
		;;
	esac
done

############################################################################
# Delete temporary file
############################################################################

delete
############################################################################

}


