#/bin/bash
#
# All Rights Reserved, Copyright (c) FUJITSU LIMITED 2012-2017
#
#	Configuration Tool for Oracle VM Server for SPARC
#
# Revision 3.0  2017/11/16
#
# pattern1_primary.sh

primary_pattern1()
{
DOMAIN=primary

#---set default------------------------------------------------------------#
#CPU=4
#MEM=8192

CPU_MIN=1
CPU_DEF=2
MEM_MIN=4096
MEM_DEF=4096

STPORT="5000"
EDPORT="5100"
VDS="primary-vds0"
CONFIG=config_initial
#--------------------------------------------------------------------------#
TITLE=" 1.Configure a Primary Domain"
DKIND="primary"
PATTERN="Pattern 1"
work_out="${work_dir}"

############################################################################
# Assign CPU
############################################################################
#	echo "CPU    : $CPU disabled" >> $work_out/cpu.tmp

header "$TITLE" "$PATTERN"
print_cpu
print "# CPU cores                                                                      [1/9]"
print ""
print "Assign CPU cores to the primary domain."
print ""
cat $work_dir/cpulist.tmp
print "t:top menu  q:quit"
print "---------------------------------------------------------------------------------------"
print ""

domain_cpu 1

if [ -f $work_out/cpu.info ];then
        echo "=== The following quantity of CPU cores will be allocated ==="
        cat $work_out/cpu.info
else
        echo ""
        echo "CPU core will not be allocated."
fi
echo "---------------------------------------------------------------------------------------"
echo "Please press the enter key."
read key

############################################################################
# Setting Memory
############################################################################
#	echo "Memory : $MEM MB for the primary domain $DOMAIN" >> $work_out/mem.tmp

header "$TITLE" "$PATTERN"
print_memory
print "# Memory                                                                         [2/9]"
print ""
print "Assign memory to the primary domain."
print ""
cat $work_dir/memlist.tmp
print "t:top menu  q:quit"
print "---------------------------------------------------------------------------------------"
print ""

domain_memory

echo "=== The following memory will be allocated ==="
cat $work_out/mem.tmp
echo "---------------------------------------------------------------------------------------"
echo "Please press the enter key."
read key

############################################################################
# Creating VSW
############################################################################

#COUNT=0
#for i in $NET
#do
#	PHYS="`dladm show-phys | grep -w $i | awk '{print $6}'`"
#	echo "VSW    : primary-vsw$COUNT : $i was allocated." >> $work_out/vsw.tmp
#	echo "VSW    : primary-vsw$COUNT : $i [$PHYS] was allocated." >> $work_out/vsw.info
#	COUNT=`expr $COUNT + 1`
#done

#V3.0
header "$TITLE" "$PATTERN"
print "# Virtual switch                                                                 [3/9]"
print ""
print "Do you wish to create a virtual switch service (vsw) to enable networking between the"
print "virtual network (vnet) devices in logical domains?"
print ""
print "t:top menu  q:quit"
print "---------------------------------------------------------------------------------------"
print ""

while :
do
        YN=""
        echo "Create a virtual switch service? ([y]/n) ==> \c"
        read YN
        case ${YN:-y} in
                [t])    top
                        ;;
                [q])    quit
                        ;;
                [y])    while :
                        do
                                echo "Enter the quantity of virtual switch services [1] ==> \c"
                                read NUM_of_SW
                                expr ${NUM_of_SW:-1} + 1 > /dev/null 2>&1
                                if [ $? = 0 ];then
                                        #ver1.1
                                        if [ ${NUM_of_SW:-1} -le 768 ];then
                                                break 2
                                        else
                                                echo "ERROR: Invalid input value."
                                        fi
                                else
                                        if [ ${NUM_of_SW:-1} = t ];then
                                                top
                                                continue
                                        elif [ ${NUM_of_SW:-1} = q ];then
                                                quit
                                                continue
                                        else
                                                echo "ERROR: Invalid input value."
                                        fi
                                fi
                        done
                        ;;
                [n])    break
                        ;;
                  *)    continue
                        ;;
        esac
done

COUNT01=0
while [ "${YN:-y}" != n -a $COUNT01 -lt ${NUM_of_SW:-1} ]
do
        echo ""
        COUNT02=`expr $COUNT01 + 1`
        case $COUNT02 in
                  [1])  echo "=== Set the 1st virtual switch service configuration ==="
                        ;;
                  [2])  echo "=== Set the 2nd virtual switch service configuration ==="
                        ;;
                  [3])  echo "=== Set the 3rd virtual switch service configuration ==="
                        ;;
                [4-9])  echo "=== Set the ${COUNT02}th virtual switch service configuration ==="
                        ;;
                    *)  echo "=== Set the next virtual switch service configuration ==="
                        ;;
        esac
        add_vsw $COUNT01
        COUNT01=`expr $COUNT01 + 1`
done

if [ -f $work_out/vsw.tmp ];then
        echo ""
        echo "=== These virtual switch service settings will be created ==="
        cat $work_out/vsw.info
else
        echo ""
        echo "A virtual switch service will not be created."
fi
echo "---------------------------------------------------------------------------------------"
echo "Please press the enter key."
read key

############################################################################
# Setting VCC
############################################################################

echo "VCC    : primary-vcc0 will use the port range of $STPORT to $EDPORT" >> $work_out/vcc.tmp

############################################################################
# Setting VDS
############################################################################

echo "VDS    : Add $VDS to the $DOMAIN domain." >> $work_out/vds.tmp

############################################################################
# Check configuration file name
############################################################################

header "$TITLE" "$PATTERN"
CONF_O=$CONFIG
config_name $CONF_O

echo ""
echo "=== The configuration will be saved as the following ==="
echo "The configuration name : $CONFIG" | tee -a $work_out/config.tmp
echo "---------------------------------------------------------------------------------------"
echo "Please press the enter key."
read key

############################################################################
# Confirming configuration
############################################################################

header "$TITLE" "$PATTERN"
print "The following primary domain configuration will be set."
print ""
print "======= Your configuration information for primary domain ============================="
printf "Domain : %s\n" "$DOMAIN"
cat $work_out/cpu.info
cat $work_out/mem.tmp
#printf "CPU    : %s cores for the primary domain\n" "$CPU"
#printf "Memory : %s MB for the primary domain\n" "$MEM"
print "-------------------------------------------------------------------"
cat $work_out/vcc.tmp
cat $work_out/vsw.info
print "-------------------------------------------------------------------"
cat $work_out/config.tmp
print "======================================================================================="
print ""

############################################################################
# Execution and creating of configuration file
############################################################################

EXE=$conf_dir/${DOMAIN}-${DATE}.sh

save_exec 0

############################################################################
# Delete temporary file 
############################################################################

delete
############################################################################

}
