#/bin/bash
#
# All Rights Reserved, Copyright (c) FUJITSU LIMITED 2012-2017
#
#	Configuration Tool for Oracle VM Server for SPARC
#
# Revision 3.0  2017/11/26
#
# pattern3_io_root.sh

io_root_pattern3()
{

#---set default------------------------------------------------------------#
CPU_MIN=1
CPU_DEF=1
MEM_MIN=4096
MEM_DEF=4096
AUTOBOOT=false
BOOTDISK=vdisk0
VCPORT=5000
VDS="primary-vds0"
MIN_VDISK=1
#--------------------------------------------------------------------------#
#DOMAIN="guest"
TITLE=" 2.Configure a I/O root Domain"
DKIND="I/O root"
PATTERN="Pattern 3"
#work_out="${work_dir}/${DOMAIN}"

#--------------------------------------------------------------------------#

############################################################################
# Creating Domain
############################################################################
dom_title()
{
	print "# Logical domain name                                                            [1/5]"
	print ""
	print "Specify a logical domain name for the I/O root domain. "
	print ""
	print "t:top menu  q:quit"
	print "---------------------------------------------------------------------------------------"
	print ""
}

header "$TITLE" "$PATTERN"
dom_title
NUM=1
list=(`ldm list-io -p | grep BUS | grep -v primary`)
IOMAX=`echo ${#list[@]}`

if [ ${IOMAX} -eq 0 ];then
	echo "---------------------------------------------------------------------------------------"
	echo "Please remove the I/O device from the control domain before you create the I/O root domain."
	echo "---------------------------------------------------------------------------------------"
	echo ""
	echo "Please press the enter key. \c"
	read key
	delete
	menu
	exit 0
fi

while :
do
        echo "Enter the quantity of I/O root domains that you wish to create.[1] ==> \c"
        read NUM
        case ${NUM:-1} in
          [t])  top
                ;;
          [q])  quit
                ;;
            *)  expr ${NUM:-1} + 1 > /dev/null 2>&1
                if [ $? = 0 ];then
                        if [ ${NUM:-1} -lt 1 ];then
                                echo "ERROR: Invalid input value."
				echo "ERROR: Please enter a number between 1 and ${IOMAX}"
                        elif [ ${NUM:-1} -gt ${IOMAX} ];then
				echo "ERROR: Invalid input value."
				echo "ERROR: Please enter a number between 1 and ${IOMAX}"
			else
                                NUM=${NUM:-1}
                                break
                        fi
                else
                        echo "ERROR: Invalid input value."
                fi
                ;;
        esac
done

NUM_DOM=`expr $NUM`
GUEST_COUNT=0
while [ $GUEST_COUNT -lt $NUM_DOM ]
do
	echo ""
	h01=`expr $GUEST_COUNT + 1`
	case $h01 in
			[1])	echo "=== Creating the 1st Domain ==="
			;;
			[2])	header "$TITLE" "$PATTERN" ; dom_title
			echo "=== Creating the 2nd Domain ==="
			;;
			[3])	header "$TITLE" "$PATTERN" ; dom_title
			echo "=== Creating the 3rd Domain ==="
			;;
			[4-10])	header "$TITLE" "$PATTERN" ; dom_title
			echo "=== Creating the ${h01}th Domain ==="
			;;
			*)	header "$TITLE" "$PATTERN" ; dom_title
			echo "=== Creating next Domain ==="
			;;
	esac

	domain_name

	work_out="${work_dir}/${DOMAIN}"

	echo ""
	echo "=== The following logical domain name will be set ==="
	echo "Domain : $DOMAIN" | tee -a $work_out/dom.tmp
	echo "---------------------------------------------------------------------------------------"
	echo "Please press the enter key."
	read key

############################################################################
# CPU cores
############################################################################
	print_cpu
	header "$TITLE" "$PATTERN"
	print "# CPU core                                                                       [2/5]"
	print ""
	printf "Assign CPU cores to the domain %s.\n" "$DOMAIN"
	print ""
	print "### Current CPU allocation for each domain ###"
	print ""
	cat $work_dir/cpulist.tmp
	print "t:top menu  q:quit"
	print "---------------------------------------------------------------------------------------"
	print ""

	domain_cpu 1

	if [ -f $work_out/cpu.info ];then
		echo "=== The following quantity of CPU cores will be allocated ==="
		cat $work_out/cpu.info
	else
		echo ""
		echo "CPU core will not be allocated."
	fi
	echo "---------------------------------------------------------------------------------------"
	echo "Please press the enter key."
	read key

############################################################################
# Setting Memory
############################################################################

	header "$TITLE" "$PATTERN"
	print_memory

	print "# Memory                                                                         [3/5]"
	print ""
	printf "Assign memory to the domain %s.\n" "$DOMAIN"
	print ""
	print "### The current amount of memory allocated to each domain ###"
	print ""
	cat $work_dir/memlist.tmp
	print "t:top menu  q:quit"
	print "---------------------------------------------------------------------------------------"
	print ""

	domain_memory

	echo "=== The following memory will be allocated ==="
	cat $work_out/mem.tmp
	echo "---------------------------------------------------------------------------------------"
	echo "Please press the enter key."
	read key


############################################################################
# Adding I/O
############################################################################

        header "$TITLE" "$PATTERN"
        print "# Add I/O devices to the I/O root domain.                                        [4/5]"
        print ""
        print "Please select I/O devices that you wish to add to the I/O root domain."
        print ""
        print_io
        print ""
        print "t:top menu  q:quit"
        print "---------------------------------------------------------------------------------------"
        print ""

	MAX=`ldm list-io -p| grep BUS | wc -l`

	while :
	do

	### I/O check
	FREE_IO_COUNT=0
	while read line
	do
		dom=`echo $line | sed 's/domain=//' | awk -F"|" '{print $5}'`
		if [ ! "$dom" = "primary" ];then
			dev=`echo $line | sed 's/dev=//' | awk -F"|" '{print $2}'`
			if [ -f $work_dir/io_resv.tmp ];then
				cat $work_dir/io_resv.tmp | grep $dev > /dev/null 2>&1
				if [ $? != 0 ];then
					FREE_IO_COUNT=`expr $FREE_IO_COUNT + 1`
				fi
			else
				FREE_IO_COUNT=`expr $FREE_IO_COUNT + 1`
			fi
		fi
	done < $work_dir/list_$$

	if [ $FREE_IO_COUNT -eq 0 ];then
		echo "All I/O device has been allocated."
		echo ""
		break
	fi


	### Input I/O
	while :
	do
		echo "Enter a number ==> \c"
		read NUM
		case ${NUM} in
			[t])    top
				continue
				;;
			[q])    quit
				continue
				;;
			  *)    expr ${NUM} + 1 > /dev/null 2>&1
       	                	if [ $? -ne 0 ];then
       	                        	echo "ERROR: Invalid input value."
                                	echo ""
                        	elif [ ${NUM} -ge 0 -a ${NUM} -le $MAX ];then
                               		break 
                        	else
                                	echo "ERROR: Invalid input value."
                                	echo ""
                        	fi 
				;;
		esac
	done

	FREE_IO_CHECK=0
	line=`sed -n $(expr $NUM + 1)P $work_dir/list_$$`
	dom=`echo $line | sed 's/domain=//' | awk -F"|" '{print $5}'`
	if [ ! "$dom" = "primary" ];then
		dev=`echo $line | sed 's/dev=//' | awk -F"|" '{print $2}'`
		if [ -f $work_dir/io_resv.tmp ];then
			cat $work_dir/io_resv.tmp | grep $dev > /dev/null 2>&1
			if [ $? != 0 ];then
				FREE_IO_CHECK=`expr $FREE_IO_CHECK + 1`
			fi
		else
			FREE_IO_CHECK=`expr $FREE_IO_CHECK + 1`
		fi
	fi

	if [ ! $FREE_IO_CHECK -eq 0 ];then
		echo "I/O    : added $dev to the domain $DOMAIN." >> $work_out/add_io.tmp
		echo "$dev $DOMAIN" >> $work_dir/io_resv.tmp
	else
		echo "The No. $NUM device has already been allocated to the domain."
		echo ""
		continue
	fi

	while :
	do
        	YN=""
	        echo "Do you wish to allocate more I/O device? (y/n) ==> \c"
        	read YN
        	case ${YN} in
        		[t])    top
        			continue
				;;
			[q])    quit
				continue
				;;
			[n])	break
				;;
			[y])    break
				;;
		  	*)    continue
				;;
		esac
	done

	if [ ${YN} = "n" ];then
		break
	fi

	done		


	if [ -f $work_out/add_io.tmp ];then
		echo ""
		echo "=== The following I/O device will be allocated ==="
		cat $work_out/add_io.tmp
	else
        	echo "$DOMAIN has NO I/O devices."
	fi

        echo "---------------------------------------------------------------------------------------"
        echo "Please press the enter key."
	read key

############################################################################
# Confirm VC
############################################################################
	header "$TITLE" "$PATTERN"
	print "# Virtual Console                                                                [5/5]"
	print ""
	print "Please confirm the virtual console."
	print ""
	print "t:top menu  q:quit"
	print "---------------------------------------------------------------------------------------"
	print ""

	PORT=`expr $VCPORT + $GUEST_COUNT`

	echo "VC     : primary-vcc0 $PORT" >> $work_out/vc.tmp
	echo "=== The following virtual console settings will be made ==="
	echo "VC     : the virtual console concentrator is primary-vcc0" | tee -a $work_out/vc.info
	echo "VC     : the port number is $PORT" | tee -a $work_out/vc.info
	echo "---------------------------------------------------------------------------------------"
	echo "Please press the enter key."
	read key

	GUEST_COUNT=`expr $GUEST_COUNT + 1`

############################################################################
# Setting Variables
############################################################################

	echo "OBP    : auto-boot?=$AUTOBOOT $DOMAIN" >> $work_out/var.tmp
	echo "OBP    : boot-disk=$BOOTDISK $DOMAIN" >> $work_out/var.tmp

	echo "OBP    : $DOMAIN : auto-boot?=$AUTOBOOT" >> $work_out/var.info
	echo "OBP    : $DOMAIN : boot-disk=$BOOTDISK" >> $work_out/var.info

############################################################################
# Method of installing Solaris OS
############################################################################

header "$TITLE" "$PATTERN"
print "# OS Install                                                                    "
print ""
printf "Select a method to install the Oracle Solaris OS on the logical domain %s.\n" "$DOMAIN"
print "Please select either installation from a network install server for from an iso image"
print "file."
print ""
print "t:top menu  q:quit"
print "---------------------------------------------------------------------------------------"
print ""

#cp $work_out/vnet.tmp $work_dir
#work_out=$work_dir

os_install 0

print ""

if [ -f $work_out/os.info ];then
        echo "=== The following method will be set ==="
        cat $work_out/os.info
else
        echo ""
        echo "Not decided."
fi
echo "---------------------------------------------------------------------------------------"
echo "Please press the enter key."
read key


done

############################################################################
# Confirmation of setting
############################################################################

header "$TITLE" "$PATTERN"
print "The following I/O root domain configuration will be set."
print ""

FILE=`ls -l $work_dir|grep drwxr-xr-x|awk -F" " '{print $9}'`
for i in $FILE
do
	printf "======= Your configuration information for I/O root domain %s ====================\n" "$i"
	cat $work_dir/$i/dom.tmp
	cat $work_dir/$i/cpu.info
	cat $work_dir/$i/mem.tmp
	cat $work_dir/$i/add_io.tmp
	print "-------------------------------------------------------------------"
	cat $work_dir/$i/vc.info
	cat $work_dir/$i/var.info
	print "-------------------------------------------------------------------"
	cat $work_dir/$i/os.info
	print "======================================================================================="
	print ""
done

############################################################################
# Execution and creating of configuration file
############################################################################

EXE=$conf_dir/${DOMAIN}-${DATE}.sh

save_exec 1

############################################################################
# Delete temporary file 
############################################################################

delete
############################################################################

}
